@@ -1,4 +1,4 @@
-// Copyright (C) 2015-2018 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2015-2019 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -6,6 +6,7 @@
 
 #include <config.h>
 
+#include <eval/dependency.h>
 #include <dhcpsrv/client_class_def.h>
 #include <dhcpsrv/cfgmgr.h>
 #include <boost/foreach.hpp>
@@ -136,6 +137,11 @@ ClientClassDef::setCfgOption(const CfgOptionPtr& cfg_option) {
     cfg_option_ = cfg_option;
 }
 
+bool
+ClientClassDef::dependOnClass(const std::string& name) const {
+    return (isc::dhcp::dependOnClass(match_expr_, name));
+}
+
 bool
 ClientClassDef::equals(const ClientClassDef& other) const {
     return ((name_ == other.name_) &&
@@ -279,6 +285,27 @@ ClientClassDictionary::getClasses() const {
     return (list_);
 }
 
+bool
+ClientClassDictionary::dependOnClass(const std::string& name,
+                                     std::string& dependent_class) const {
+    // Skip previous classes as they should not depend on name.
+    bool found = false;
+    for (ClientClassDefList::iterator this_class = list_->begin();
+         this_class != list_->end(); ++this_class) {
+        if (found) {
+            if ((*this_class)->dependOnClass(name)) {
+                dependent_class = (*this_class)->getName();
+                return (true);
+            }
+        } else {
+            if ((*this_class)->getName() == name) {
+                found = true;
+            }
+        }
+    }
+    return (false);
+}
+
 bool
 ClientClassDictionary::equals(const ClientClassDictionary& other) const {
     if (list_->size() != other.list_->size()) {
@@ -314,7 +341,11 @@ ClientClassDictionary::toElement() const {
 
 std::list<std::string>
 builtinNames = {
-    "ALL", "KNOWN", "UNKNOWN"
+    // DROP is not in this list because it is special but not built-in.
+    // In fact DROP is set from an expression as callouts can drop
+    // directly the incoming packet. The expression must not depend on
+    // KNOWN/UNKNOWN which are set far after the drop point.
+    "ALL", "KNOWN", "UNKNOWN", "BOOTP"
 };
 
 std::list<std::string>
