@@ -553,10 +553,11 @@ Pools4ListParser::parse(PoolStoragePtr pools, ConstElementPtr pools_list) {
 
 //****************************** SubnetConfigParser *************************
 
-SubnetConfigParser::SubnetConfigParser(uint16_t family)
+SubnetConfigParser::SubnetConfigParser(uint16_t family, bool check_iface)
     : pools_(new PoolStorage()),
       address_family_(family),
-      options_(new CfgOption()) {
+      options_(new CfgOption()),
+      check_iface_(check_iface) {
     relay_info_.reset(new isc::dhcp::Network::RelayInfo());
 }
 
@@ -677,8 +678,8 @@ SubnetConfigParser::createSubnet(ConstElementPtr params) {
 
 //****************************** Subnet4ConfigParser *************************
 
-Subnet4ConfigParser::Subnet4ConfigParser()
-    :SubnetConfigParser(AF_INET) {
+Subnet4ConfigParser::Subnet4ConfigParser(bool check_iface)
+    : SubnetConfigParser(AF_INET, check_iface) {
 }
 
 Subnet4Ptr
@@ -732,11 +733,9 @@ void
 Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
                                 asiolink::IOAddress addr, uint8_t len) {
     // Subnet ID is optional. If it is not supplied the value of 0 is used,
-    // which means autogenerate.
-    SubnetID subnet_id = 0;
-    if (params->contains("id")) {
-        subnet_id = static_cast<SubnetID>(getInteger(params, "id"));
-    }
+    // which means autogenerate. The value was inserted earlier by calling
+    // SimpleParser4::setAllDefaults.
+    SubnetID subnet_id = static_cast<SubnetID>(getInteger(params, "id"));
 
     Subnet4Ptr subnet4(new Subnet4(addr, len, Triplet<uint32_t>(),
                                    Triplet<uint32_t>(), Triplet<uint32_t>(),
@@ -831,7 +830,7 @@ Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
     if (params->contains("interface")) {
         std::string iface = getString(params, "interface");
         if (!iface.empty()) {
-            if (!IfaceMgr::instance().getIface(iface)) {
+            if (check_iface_ && !IfaceMgr::instance().getIface(iface)) {
                 ConstElementPtr error = params->get("interface");
                 isc_throw(DhcpConfigError, "Specified network interface name " << iface
                           << " for subnet " << subnet4->toText()
@@ -932,12 +931,17 @@ Subnet4ConfigParser::initSubnet(data::ConstElementPtr params,
 
 //**************************** Subnets4ListConfigParser **********************
 
+Subnets4ListConfigParser::Subnets4ListConfigParser(bool check_iface)
+    : check_iface_(check_iface) {
+}
+
 size_t
-Subnets4ListConfigParser::parse(SrvConfigPtr cfg, ConstElementPtr subnets_list) {
+Subnets4ListConfigParser::parse(SrvConfigPtr cfg,
+                                ConstElementPtr subnets_list) {
     size_t cnt = 0;
     BOOST_FOREACH(ConstElementPtr subnet_json, subnets_list->listValue()) {
 
-        Subnet4ConfigParser parser;
+        Subnet4ConfigParser parser(check_iface_);
         Subnet4Ptr subnet = parser.parse(subnet_json);
         if (subnet) {
 
@@ -962,7 +966,7 @@ Subnets4ListConfigParser::parse(Subnet4Collection& subnets,
     size_t cnt = 0;
     BOOST_FOREACH(ConstElementPtr subnet_json, subnets_list->listValue()) {
 
-        Subnet4ConfigParser parser;
+        Subnet4ConfigParser parser(check_iface_);
         Subnet4Ptr subnet = parser.parse(subnet_json);
         if (subnet) {
             try {
@@ -1112,8 +1116,8 @@ PdPoolsListParser::parse(PoolStoragePtr pools, ConstElementPtr pd_pool_list) {
 
 //**************************** Subnet6ConfigParser ***********************
 
-Subnet6ConfigParser::Subnet6ConfigParser()
-    : SubnetConfigParser(AF_INET6) {
+Subnet6ConfigParser::Subnet6ConfigParser(bool check_iface)
+    : SubnetConfigParser(AF_INET6, check_iface) {
 }
 
 Subnet6Ptr
@@ -1269,7 +1273,7 @@ Subnet6ConfigParser::initSubnet(data::ConstElementPtr params,
     // Get interface name. If it is defined, then the subnet is available
     // directly over specified network interface.
     if (!iface.unspecified() && !iface.empty()) {
-        if (!IfaceMgr::instance().getIface(iface)) {
+        if (check_iface_ && !IfaceMgr::instance().getIface(iface)) {
             ConstElementPtr error = params->get("interface");
             isc_throw(DhcpConfigError, "Specified network interface name " << iface
                       << " for subnet " << subnet6->toText()
@@ -1324,12 +1328,17 @@ Subnet6ConfigParser::initSubnet(data::ConstElementPtr params,
 
 //**************************** Subnet6ListConfigParser ********************
 
+Subnets6ListConfigParser::Subnets6ListConfigParser(bool check_iface)
+    : check_iface_(check_iface) {
+}
+
 size_t
-Subnets6ListConfigParser::parse(SrvConfigPtr cfg, ConstElementPtr subnets_list) {
+Subnets6ListConfigParser::parse(SrvConfigPtr cfg,
+                                ConstElementPtr subnets_list) {
     size_t cnt = 0;
     BOOST_FOREACH(ConstElementPtr subnet_json, subnets_list->listValue()) {
 
-        Subnet6ConfigParser parser;
+        Subnet6ConfigParser parser(check_iface_);
         Subnet6Ptr subnet = parser.parse(subnet_json);
 
         // Adding a subnet to the Configuration Manager may fail if the
@@ -1352,7 +1361,7 @@ Subnets6ListConfigParser::parse(Subnet6Collection& subnets,
     size_t cnt = 0;
     BOOST_FOREACH(ConstElementPtr subnet_json, subnets_list->listValue()) {
 
-        Subnet6ConfigParser parser;
+        Subnet6ConfigParser parser(check_iface_);
         Subnet6Ptr subnet = parser.parse(subnet_json);
         if (subnet) {
             try {
