@@ -26,6 +26,10 @@ using namespace isc::util;
 namespace isc {
 namespace dhcp {
 
+SharedNetwork4Parser::SharedNetwork4Parser(bool check_iface)
+    : check_iface_(check_iface) {
+}
+
 SharedNetwork4Ptr
 SharedNetwork4Parser::parse(const data::ConstElementPtr& shared_network_data) {
     SharedNetwork4Ptr shared_network;
@@ -46,7 +50,19 @@ SharedNetwork4Parser::parse(const data::ConstElementPtr& shared_network_data) {
 
         // interface is an optional parameter
         if (shared_network_data->contains("interface")) {
-            shared_network->setIface(getString(shared_network_data, "interface"));
+            std::string iface = getString(shared_network_data, "interface");
+            if (!iface.empty()) {
+                if (check_iface_ && !IfaceMgr::instance().getIface(iface)) {
+                    ConstElementPtr error =
+                        shared_network_data->get("interface");
+                    isc_throw(DhcpConfigError,
+                              "Specified network interface name " << iface
+                              << " for shared network " << name
+                              << " is not present in the system ("
+                              << error->getPosition() << ")");
+                }
+                shared_network->setIface(iface);
+            }
         }
 
         if (shared_network_data->contains("option-data")) {
@@ -61,7 +77,7 @@ SharedNetwork4Parser::parse(const data::ConstElementPtr& shared_network_data) {
             auto json = shared_network_data->get("subnet4");
 
             // Create parser instance of subnet4.
-            Subnets4ListConfigParser parser;
+            Subnets4ListConfigParser parser(check_iface_);
             Subnet4Collection subnets;
             parser.parse(subnets, json);
 
@@ -194,6 +210,10 @@ SharedNetwork4Parser::parse(const data::ConstElementPtr& shared_network_data) {
     return (shared_network);
 }
 
+SharedNetwork6Parser::SharedNetwork6Parser(bool check_iface)
+    : check_iface_(check_iface) {
+}
+
 SharedNetwork6Ptr
 SharedNetwork6Parser::parse(const data::ConstElementPtr& shared_network_data) {
     SharedNetwork6Ptr shared_network;
@@ -222,6 +242,7 @@ SharedNetwork6Parser::parse(const data::ConstElementPtr& shared_network_data) {
             ifaceid = getString(shared_network_data, "interface-id");
         }
 
+        // Interface is an optional parameter
         Optional<std::string> iface;
         if (shared_network_data->contains("interface")) {
             iface = getString(shared_network_data, "interface");
@@ -248,17 +269,20 @@ SharedNetwork6Parser::parse(const data::ConstElementPtr& shared_network_data) {
             shared_network->setInterfaceId(opt);
         }
 
-        // Get interface name. If it is defined, then the subnet is available
+        // Set interface name. If it is defined, then subnets are available
         // directly over specified network interface.
         if (!iface.unspecified() && !iface.empty()) {
+            if (check_iface_ && !IfaceMgr::instance().getIface(iface)) {
+                ConstElementPtr error = shared_network_data->get("interface");
+                isc_throw(DhcpConfigError,
+                          "Specified network interface name " << iface
+                          << " for shared network " << name
+                          << " is not present in the system ("
+                          << error->getPosition() << ")");
+            }
             shared_network->setIface(iface);
         }
 
-        // Interface is an optional parameter
-        if (shared_network_data->contains("interface")) {
-            shared_network->setIface(getString(shared_network_data, "interface"));
-        }
-
         if (shared_network_data->contains("rapid-commit")) {
             shared_network->setRapidCommit(getBoolean(shared_network_data,
                                                       "rapid-commit"));
@@ -302,7 +326,7 @@ SharedNetwork6Parser::parse(const data::ConstElementPtr& shared_network_data) {
             auto json = shared_network_data->get("subnet6");
 
             // Create parser instance of subnet6.
-            Subnets6ListConfigParser parser;
+            Subnets6ListConfigParser parser(check_iface_);
             Subnet6Collection subnets;
             parser.parse(subnets, json);
 
