@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -29,6 +29,8 @@
 #include <cc/data.h>
 #include <cc/user_context.h>
 #include <cc/simple_parser.h>
+#include <util/strutil.h>
+
 #include <boost/shared_ptr.hpp>
 #include <vector>
 #include <stdint.h>
@@ -38,6 +40,98 @@ namespace dhcp {
 
 class CfgMgr;
 
+/// @brief Convenience container for conveying DDNS behaviorial parameters
+/// It is intended to be created per Packet exchange using the selected
+/// subnet passed into functions that require them
+class DdnsParams {
+public:
+    /// @brief Default constructor
+    DdnsParams() : subnet_(), d2_client_enabled_(false) {};
+
+    /// @brief Constructor for DHPCv4 subnets
+    ///
+    /// @param subnet Pointer to Subnet4 instance to use for fetching
+    /// parameter values (typically this is the selected subnet).
+    /// @param d2_client_enabled flag which indicates whether or not
+    /// D2Client is enabled (typically the value should come from
+    /// global D2Client configuration).
+    DdnsParams(const Subnet4Ptr& subnet, bool d2_client_enabled)
+        : subnet_(boost::dynamic_pointer_cast<Subnet>(subnet)),
+          d2_client_enabled_(d2_client_enabled) {}
+
+    /// @brief Constructor for DHPCv6 subnets
+    ///
+    /// @param subnet Pointer to Subnet6 instance to use for fetching
+    /// parameter values (typically this is the selected subnet).
+    /// @param d2_client_enabled flag which indicates whether or not
+    /// D2Client is enabled (typically the value should come from
+    /// global D2Client configuration).
+    DdnsParams(const Subnet6Ptr& subnet, bool d2_client_enabled)
+        : subnet_(boost::dynamic_pointer_cast<Subnet>(subnet)),
+          d2_client_enabled_(d2_client_enabled) {}
+
+    /// @brief Returns whether or not DHCP DDNS updating is enabled.
+    /// The value is the logical AND of d2_client_enabled_ and
+    /// the value returned by subnet_'s getDdnsSendUpdates().  It
+    /// @return True if updates are enabled, false otherwise or if
+    /// subnet_ is empty.
+    bool getEnableUpdates() const;
+
+    /// @brief Returns whether or not Kea should perform updates, even if
+    /// client requested no updates.
+    /// @return The value from the subnet_ or false if subnet_ is empty.
+    bool getOverrideNoUpdate() const;
+
+    /// @brief Returns whether or not Kea should perform updates, even if
+    /// client requested delegation.
+    /// @return The value from the subnet_ or false if subnet_ is empty.
+    bool getOverrideClientUpdate() const;
+
+    /// @brief Returns how Kea should handle the domain-name supplied by
+    /// the client.
+    /// @return The value from the subnet_ or RCM_NEVER if subnet_ is empty.
+    D2ClientConfig::ReplaceClientNameMode getReplaceClientNameMode() const;
+
+    /// @brief Returns the Prefix Kea should use when generating domain-names.
+    /// @return The value from the subnet_ or an empty string if subnet_ is empty.
+    std::string getGeneratedPrefix() const;
+
+    /// @brief Returns the suffix Kea should use when to qualify partial
+    /// domain-names.
+    /// @return The value from the subnet_ or an empty string if subnet_ is empty.
+    std::string getQualifyingSuffix() const;
+
+    /// @brief Returns the regular expression describing invalid characters
+    /// for client hostnames.  If empty, host name scrubbing should not be done.
+    /// @return The value from the subnet_ or an empty string if subnet_ is empty.
+    std::string getHostnameCharSet() const;
+
+    /// @brief Returns the string to replace invalid characters when scrubbing
+    /// hostnames. Meaningful only if hostname_char_set_ is not empty.
+    /// @return The value from the subnet_ or an empty string if subnet_ is empty.
+    std::string getHostnameCharReplacement() const;
+
+    /// @brief Returns a regular expression string sanitizer
+    ///
+    /// If the value returned by getHostnameCharSet() is not empty, then it is
+    /// used in conjunction the value returned by getHostnameCharReplacment()
+    /// (which may be empty) to create and return a StringSanitizer instance.
+    /// Otherwise it will return an empty pointer.
+    ///
+    /// @return pointer to the StringSanitizer instance or an empty pointer
+    /// @throw BadValue if the compilation fails.
+    isc::util::str::StringSanitizerPtr getHostnameSanitizer() const;
+
+private:
+    /// @brief Subnet from which values should be fetched.
+    SubnetPtr subnet_;
+
+    /// @brief Flag indicating whether or not the D2Client is enabled.
+    bool d2_client_enabled_;
+};
+
+/// @brief Defines a pointer for DdnsParams instances.
+typedef boost::shared_ptr<DdnsParams> DdnsParamsPtr;
 
 /// @brief Specifies current DHCP configuration
 ///
@@ -405,22 +499,27 @@ public:
         return (hooks_config_);
     }
 
-    /// @brief Fetches the DDNS parameters for a given subnet.
+    /// @brief Fetches the DDNS parameters for a given DHCPv4 subnet.
     ///
-    /// Creates a DdnsParams structure populated with the scoped
-    /// values for DDNS behaviorial parameters. The scope mode used
-    /// is Network::ALL.
+    /// Creates a DdnsParams structure which retain and thereafter
+    /// use the given subnet to fetch DDNS behaviorial parameters.
+    /// The values are fetched with the inheritance scope mode
+    /// of Network::ALL.
     ///
-    /// - enable_updates_ = (DhcpDdns.enable-updates && scoped ddns-enable-updates)
-    /// - override_no_update_ = scoped ddns-override-no-update
-    /// - override_client_update_ = scoped ddns-override-no-update
-    /// - replace_client_name_mode_  = scoped ddns-replace-client-name
-    /// - generated_prefix_ =  scoped ddns-generated-prefix
-    /// - qualifying_suffix_ = scoped ddns-qualifying-suffix
-    ///
-    /// @param subnet Subnet for which DDNS parameters are desired.
+    /// @param subnet DHCPv4 Subnet for which DDNS parameters are desired.
     /// @return pointer to DddnParams instance
-    DdnsParamsPtr getDdnsParams(const Subnet& subnet) const;
+    DdnsParamsPtr getDdnsParams(const Subnet4Ptr& subnet) const;
+
+    /// @brief Fetches the DDNS parameters for a given DHCPv6 subnet.
+    ///
+    /// Creates a DdnsParams structure which retain and thereafter
+    /// use the given subnet to fetch DDNS behaviorial parameters.
+    /// The values are fetched with the inheritance scope mode
+    /// of Network::ALL.
+    ///
+    /// @param subnet DHCPv6 Subnet for which DDNS parameters are desired.
+    /// @return pointer to DddnParams instance
+    DdnsParamsPtr getDdnsParams(const Subnet6Ptr& subnet) const;
 
     /// @brief Copies the current configuration to a new configuration.
     ///
