@@ -9,6 +9,7 @@
 #include <dhcp/dhcp6.h>
 #include <dhcp/option.h>
 #include <dhcp/option_string.h>
+#include <dhcp/tests/iface_mgr_test_config.h>
 #include <dhcpsrv/cfg_shared_networks.h>
 #include <dhcpsrv/cfg_subnets6.h>
 #include <dhcpsrv/parsers/dhcp_parsers.h>
@@ -25,6 +26,7 @@
 using namespace isc;
 using namespace isc::asiolink;
 using namespace isc::dhcp;
+using namespace isc::dhcp::test;
 using namespace isc::test;
 
 namespace {
@@ -1397,4 +1399,44 @@ TEST(CfgSubnets6Test, hostnameSanitizierValidation) {
     }
 }
 
+// This test verifies that the optional interface check works as expected.
+TEST(CfgSubnets6Test, iface) {
+    // Create a configuration.
+    std::string json =
+        "        {"
+        "            \"id\": 1,\n"
+        "            \"subnet\": \"2001:db8:1::/64\", \n"
+        "            \"interface\": \"eth1\"\n"
+        "        }";
+
+    data::ElementPtr elems;
+    ASSERT_NO_THROW(elems = data::Element::fromJSON(json))
+        << "invalid JSON:" << json << "\n test is broken";
+
+    // The interface check can be disabled.
+    Subnet6ConfigParser parser_no_check(false);
+    Subnet6Ptr subnet;
+    EXPECT_NO_THROW(subnet = parser_no_check.parse(elems));
+    ASSERT_TRUE(subnet);
+    EXPECT_FALSE(subnet->getIface().unspecified());
+    EXPECT_EQ("eth1", subnet->getIface().get());
+
+    // Retry with the interface check enabled.
+    Subnet6ConfigParser parser;
+    EXPECT_THROW(parser.parse(elems), DhcpConfigError);
+
+    // Configure default test interfaces.
+    IfaceMgrTestConfig config(true);
+
+    EXPECT_NO_THROW(subnet = parser_no_check.parse(elems));
+    ASSERT_TRUE(subnet);
+    EXPECT_FALSE(subnet->getIface().unspecified());
+    EXPECT_EQ("eth1", subnet->getIface().get());
+
+    EXPECT_NO_THROW(subnet = parser.parse(elems));
+    ASSERT_TRUE(subnet);
+    EXPECT_FALSE(subnet->getIface().unspecified());
+    EXPECT_EQ("eth1", subnet->getIface().get());
+}
+
 } // end of anonymous namespace
