@@ -1,4 +1,4 @@
-// Copyright (C) 2014-2019 Internet Systems Consortium, Inc. ("ISC")
+// Copyright (C) 2014-2020 Internet Systems Consortium, Inc. ("ISC")
 //
 // This Source Code Form is subject to the terms of the Mozilla Public
 // License, v. 2.0. If a copy of the MPL was not distributed with this
@@ -196,6 +196,7 @@ TEST(PgSqlOpenTest, OpenDatabase) {
 
     // Tidy up after the test
     destroyPgSQLSchema();
+    LeaseMgrFactory::destroy();
 }
 
 /// @brief Check that database can be opened with Multi-Threading
@@ -221,6 +222,7 @@ TEST(PgSqlOpenTest, OpenDatabaseMultiThreading) {
 
     // Tidy up after the test
     destroyPgSQLSchema();
+    LeaseMgrFactory::destroy();
 
     // Disable Multi-Threading.
     MultiThreadingMgr::instance().setMode(false);
@@ -295,6 +297,21 @@ TEST_F(PgSqlLeaseMgrTest, updateLease4MultiThreading) {
     testUpdateLease4();
 }
 
+/// @brief Lease4 concurrent update tests
+///
+/// Checks that we are not able to concurrently update a lease in the database.
+TEST_F(PgSqlLeaseMgrTest, concurrentUpdateLease4) {
+    testConcurrentUpdateLease4();
+}
+
+/// @brief Lease4 concurrent update tests
+///
+/// Checks that we are not able to concurrently update a lease in the database.
+TEST_F(PgSqlLeaseMgrTest, concurrentUpdateLease4MultiThreading) {
+    MultiThreadingMgr::instance().setMode(true);
+    testConcurrentUpdateLease4();
+}
+
 /// @brief Check GetLease4 methods - access by Hardware Address
 TEST_F(PgSqlLeaseMgrTest, getLease4HWAddr1) {
     testGetLease4HWAddr1();
@@ -730,6 +747,21 @@ TEST_F(PgSqlLeaseMgrTest, updateLease6MultiThreading) {
     testUpdateLease6();
 }
 
+/// @brief Lease6 concurrent update tests
+///
+/// Checks that we are not able to concurrently update a lease in the database.
+TEST_F(PgSqlLeaseMgrTest, concurrentUpdateLease6) {
+    testConcurrentUpdateLease6();
+}
+
+/// @brief Lease6 concurrent update tests
+///
+/// Checks that we are not able to concurrently update a lease in the database.
+TEST_F(PgSqlLeaseMgrTest, concurrentUpdateLease6MultiThreading) {
+    MultiThreadingMgr::instance().setMode(true);
+    testConcurrentUpdateLease6();
+}
+
 /// @brief DHCPv4 Lease recreation tests
 ///
 /// Checks that the lease can be created, deleted and recreated with
